// 
// Copyright (C) 2009, NinjaTrader LLC <www.ninjatrader.com>.
// NinjaTrader reserves the right to modify or overwrite this NinjaScript component with each release.
//
#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// A demonstration of how to change a font.
    /// </summary>
    [Description("A demonstration of how to change a font.")]
    public class SampleChangeFont : Indicator
    {
        #region Variables
		private Font	largeFont = new Font("Arial", 12);		// This variable holds the large font.
		private Font	smallFont = new Font("Arial", 8);		// This variable holds the small font.
		#endregion
		
        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
            CalculateOnBarClose	= true;
            Overlay				= true;
            PriceTypeSupported	= false;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			if (CurrentBar < 1)
				return;
			
			// If the close is greater than the open, draw the high price with the larger font.
			if (Close[0] > Open[0])
			{
				DrawText("highText", true, High[0].ToString(), 1, High[0] + 2 * TickSize, 0, Color.Green, largeFont, StringAlignment.Near, Color.Transparent, Color.Transparent, 0);
				DrawText("lowText", true, Low[0].ToString(), 1, Low[0] - 2 * TickSize, 0, Color.Red, smallFont, StringAlignment.Near, Color.Transparent, Color.Transparent, 0);
			}
			// If the close is less than the open, draw the low price with the larger font.
			else if (Close[0] < Open[0])
			{
				DrawText("highText", true, High[0].ToString(), 1, High[0] + 2 * TickSize, 0, Color.Green, smallFont, StringAlignment.Near, Color.Transparent, Color.Transparent, 0);
				DrawText("lowText", true, Low[0].ToString(), 1, Low[0] - 2 * TickSize, 0, Color.Red, largeFont, StringAlignment.Near, Color.Transparent, Color.Transparent, 0);
			}
			// If the closes are equal, draw the prices with the same font.
			else
			{
				DrawText("highText", true, High[0].ToString(), 1, High[0] + 2 * TickSize, 0, Color.Green, smallFont, StringAlignment.Near, Color.Transparent, Color.Transparent, 0);
				DrawText("lowText", true, Low[0].ToString(), 1, Low[0] - 2 * TickSize, 0, Color.Red, smallFont, StringAlignment.Near, Color.Transparent, Color.Transparent, 0);
			}			
		}
		
		// The OnTermination() method releases all the extra resources used by this indicator.
		protected override void OnTermination()
		{
			// Every other .Dispose() is to clean up resources created during the indicator's life span. In this case, we want to clean up the two Font objects we created.
			largeFont.Dispose();
			smallFont.Dispose();
		}
		
        #region Properties
        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private SampleChangeFont[] cacheSampleChangeFont = null;

        private static SampleChangeFont checkSampleChangeFont = new SampleChangeFont();

        /// <summary>
        /// A demonstration of how to change a font.
        /// </summary>
        /// <returns></returns>
        public SampleChangeFont SampleChangeFont()
        {
            return SampleChangeFont(Input);
        }

        /// <summary>
        /// A demonstration of how to change a font.
        /// </summary>
        /// <returns></returns>
        public SampleChangeFont SampleChangeFont(Data.IDataSeries input)
        {
            if (cacheSampleChangeFont != null)
                for (int idx = 0; idx < cacheSampleChangeFont.Length; idx++)
                    if (cacheSampleChangeFont[idx].EqualsInput(input))
                        return cacheSampleChangeFont[idx];

            lock (checkSampleChangeFont)
            {
                if (cacheSampleChangeFont != null)
                    for (int idx = 0; idx < cacheSampleChangeFont.Length; idx++)
                        if (cacheSampleChangeFont[idx].EqualsInput(input))
                            return cacheSampleChangeFont[idx];

                SampleChangeFont indicator = new SampleChangeFont();
                indicator.BarsRequired = BarsRequired;
                indicator.CalculateOnBarClose = CalculateOnBarClose;
#if NT7
                indicator.ForceMaximumBarsLookBack256 = ForceMaximumBarsLookBack256;
                indicator.MaximumBarsLookBack = MaximumBarsLookBack;
#endif
                indicator.Input = input;
                Indicators.Add(indicator);
                indicator.SetUp();

                SampleChangeFont[] tmp = new SampleChangeFont[cacheSampleChangeFont == null ? 1 : cacheSampleChangeFont.Length + 1];
                if (cacheSampleChangeFont != null)
                    cacheSampleChangeFont.CopyTo(tmp, 0);
                tmp[tmp.Length - 1] = indicator;
                cacheSampleChangeFont = tmp;
                return indicator;
            }
        }
    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// A demonstration of how to change a font.
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.SampleChangeFont SampleChangeFont()
        {
            return _indicator.SampleChangeFont(Input);
        }

        /// <summary>
        /// A demonstration of how to change a font.
        /// </summary>
        /// <returns></returns>
        public Indicator.SampleChangeFont SampleChangeFont(Data.IDataSeries input)
        {
            return _indicator.SampleChangeFont(input);
        }
    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// A demonstration of how to change a font.
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.SampleChangeFont SampleChangeFont()
        {
            return _indicator.SampleChangeFont(Input);
        }

        /// <summary>
        /// A demonstration of how to change a font.
        /// </summary>
        /// <returns></returns>
        public Indicator.SampleChangeFont SampleChangeFont(Data.IDataSeries input)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.SampleChangeFont(input);
        }
    }
}
#endregion
